@@ -6,6 +6,8 @@ import org.maemo.hermes.engine.twitter.provider
 import org.maemo.hermes.engine.gravatar.provider
 import org.maemo.hermes.engine.linkedin.provider
 from org.maemo.hermes.gui.gtkui import HermesGUI
+import httplib, urllib
+httplib.HTTPConnection.debuglevel = 1   
 
 # -- Check environment...
 #
