@@ -25,7 +25,12 @@ class Friend():
         return "Friend %s" % self.get_name()
     
     # public accessors -----------------
-    
+        
+    def is_interesting(self):
+        """A friend is interesting if there's more info than URLs
+           and photos."""
+        return self._attributes.has_key('bday') or self._multi_attributes.has_key('phone')
+
     def add_url(self, url):
 	if url:
 	    if not isinstance(url, basestring):
