@@ -11,8 +11,8 @@ class Service(org.maemo.hermes.engine.facebook.service.Service):
        
        
     # -----------------------------------------------------------------------
-    def __init__(self, service_id, linkedInApi):
-        org.maemo.hermes.engine.facebook.service.Service.__init__(self, service_id, None)
+    def __init__(self, service_id, linkedInApi, create_new = False):
+        org.maemo.hermes.engine.facebook.service.Service.__init__(self, service_id, None, create_new)
         self.linkedInApi = linkedInApi
 
     
@@ -21,7 +21,7 @@ class Service(org.maemo.hermes.engine.facebook.service.Service):
         friends = self.linkedInApi.get_friends()
         for friend in friends:
             self._register_friend(friend)
-
+            
 
     # -----------------------------------------------------------------------
     def is_profile_url(self, url):
